@@ -4,6 +4,7 @@ import sys
 import re
 import argparse
 import operator
+import shlex
 
 from functools import partial
 from textwrap import wrap
@@ -39,6 +40,11 @@ from dgspoc.adaptor import Adaptor
 from dgspoc.parser import ParsedOperation
 from dgspoc.parser import CheckStatement
 
+from dgspoc.batch import BatchBuilder
+
+from dgspoc.report import DGSReportFile
+from dgspoc.report import DGSReport
+
 from templateapp import TemplateBuilder
 
 from dlapp import DLQuery
@@ -59,6 +65,8 @@ class OptionSelector:
     def prepare(self):
         if self.options.template_id.strip():
             self.method = do_clear_template
+        elif self.options.filepath.strip():
+            self.method = do_delete_filepath
         else:
             if self.options.command == COMMAND.USAGE:
                 self.method = do_show_global_usage
@@ -70,6 +78,8 @@ class OptionSelector:
                     self.method = do_build_template
                 elif feature == FEATURE.SCRIPT:
                     self.method = do_build_test_script
+                elif feature == FEATURE.BATCH:
+                    self.method = do_build_batch_script
                 else:
                     exit_code = ECODE.SUCCESS if feature == 'usage' else ECODE.BAD
                     show_usage(self.options.command, exit_code=exit_code)
@@ -77,8 +87,8 @@ class OptionSelector:
                 self.method = do_search_template
             elif self.options.command == COMMAND.TEST:
                 self.method = do_testing
-            elif self.options.command == COMMAND.RUN:
-                raise Exception('TODO: Need to implement do_run_test_execution')
+            elif self.options.command == COMMAND.REPORT:
+                self.method = do_reporting
 
     def process(self):
         if callable(self.method):
@@ -205,7 +215,7 @@ def do_build_template(options):
             sys.exit(ECODE.SUCCESS)
 
     except Exception as ex:
-        print(Text(ex))
+        not options.quiet and print(Text(ex))
         sys.exit(ECODE.BAD)
 
 
@@ -240,14 +250,14 @@ def do_clear_template(options):
     if re.match(r'(?i) *([*]|_+all_+) *$', template_id):
         fmt = ('*** Failed to clear %r template reference because '
                'Describe-Get-System prohibits multiple clearing')
-        print(fmt % template_id)
+        not options.quiet and print(fmt % template_id)
         sys.exit(ECODE.BAD)
 
     if template_id:
         result = MiscArgs.get_parsed_result_as_data_or_file(data=template_id)
         if result.is_file:
             is_deleted = File.delete(result.filename)
-            print('%s %s' % ('+++' if is_deleted else '***', File.message))
+            not options.quiet and print('%s %s' % ('+++' if is_deleted else '***', File.message))
             sys.exit(ECODE.SUCCESS if is_deleted else ECODE.BAD)
         else:
             is_cleared = TemplateStorage.clear(template_id)
@@ -256,7 +266,7 @@ def do_clear_template(options):
                 message = fmt % template_id
             else:
                 message = '*** %s' % TemplateStorage.message
-            print(message)
+            not options.quiet and print(message)
             sys.exit(ECODE.SUCCESS if is_cleared else ECODE.BAD)
 
 
@@ -313,7 +323,7 @@ def get_test_from_adaptor(options):
         return test_data
     except Exception as ex:
         failure = 'AdaptorInquiryError - ({})'.format(Text(ex))
-        Printer.print(failure)
+        not options.quiet and Printer.print(failure)
         sys.exit(ECODE.BAD)
 
 
@@ -348,7 +358,7 @@ def do_testing(options):
         File.message = ''
         output = File.get_content(test_data_file)
         if File.message:
-            print('*** %s' % File.message)
+            not options.quiet and print('*** %s' % File.message)
             sys.exit(ECODE.BAD)
         print(output)
         result = DotObject(test_data=output, template='', records=[], records_count=0)
@@ -371,7 +381,7 @@ def do_testing(options):
                     result.records = records
                     result.records_count = len(records)
                 except Exception as ex:
-                    print('*** %s' % Text(ex))
+                    not options.quiet and print('*** %s' % Text(ex))
                     sys.exit(ECODE.BAD)
             else:
                 pfunc = partial(parse_template_result, test_file=test_data_file)
@@ -394,7 +404,7 @@ def do_testing(options):
                             sys.exit(ECODE.BAD)
                 except Exception as ex:
                     failure = '*** %s' % ex
-                    print(failure)
+                    not options.quiet and print(failure)
                     sys.exit(ECODE.BAD)
         else:
             sys.exit(ECODE.SUCCESS)
@@ -443,7 +453,7 @@ def do_testing(options):
                     records=records, records_count=len(records)
                 )
             except Exception as ex:
-                print('*** %s' % Text(ex))
+                not options.quiet and print('*** %s' % Text(ex))
                 sys.exit(ECODE.BAD)
         elif node.is_template:
             pfunc = partial(parse_template_result, test_data=output)
@@ -462,7 +472,7 @@ def do_testing(options):
                         sys.exit(ECODE.BAD)
             except Exception as ex:
                 failure = '*** %s' % ex
-                print(failure)
+                not options.quiet and print(failure)
                 sys.exit(ECODE.BAD)
         else:
             if not node.has_select_statement:
@@ -518,7 +528,7 @@ def do_testing(options):
 
     if node.error:
         lst = ['Error:', '------', '\n'.join(wrap(node.error, width=76)), '']
-        Printer.print(lst)
+        not options.quiet and Printer.print(lst)
         sys.exit(ECODE.BAD)
     else:
         sys.exit(ECODE.SUCCESS)
@@ -546,7 +556,7 @@ def do_build_test_script(options):
     snippet_filename = operands[0]
     snippet_content = File.get_content(snippet_filename)
     if File.message:
-        Printer.print('*** %s' % File.message)
+        not options.quiet and Printer.print('*** %s' % File.message)
         sys.exit(ECODE.BAD)
 
     node = ScriptBuilder(
@@ -557,7 +567,8 @@ def do_build_test_script(options):
     test_script = node.testscript.strip()
 
     if not test_script:
-        Printer.print('*** No script is generated for %r' % snippet_filename)
+        fmt = '*** No script is generated for %r'
+        Printer.print(fmt % snippet_filename)
         sys.exit(ECODE.BAD)
 
     if options.filename:
@@ -573,3 +584,82 @@ def do_build_test_script(options):
     else:
         print(test_script)
         sys.exit(ECODE.SUCCESS)
+
+
+def do_build_batch_script(options):
+    command, operands = options.command, list(options.operands)
+
+    # feature = ''.join(operands[:1])
+    operands = operands[1:]
+    name = '{}_batch'.format(command)
+    validate_usage(name, operands)
+    validate_example_usage(name, operands)
+
+    builder = BatchBuilder(options)
+    batch_script = builder.script
+    if batch_script:
+        if options.filename:
+            filename = options.filename
+
+            batch_script += '\ndgs report --detail' if options.detail else '\ndgs report'
+            batch_script += '\ndgs --delete=dgs_test_script_files --quiet'
+
+            is_saved = File.save(filename, batch_script)
+            if is_saved:
+                fmt = '+++ Successfully saved %r batch file.'
+                not options.quiet and print(fmt % filename)
+                sys.exit(ECODE.SUCCESS)
+            else:
+                fmt = '*** Failed to save %r batch file.'
+                not options.quiet and print(fmt % filename)
+                not options.quiet and print('*** %s' % File.message)
+                sys.exit(ECODE.BAD)
+        else:
+            print(batch_script)
+            sys.exit(ECODE.SUCCESS)
+    else:
+        msg = '*** Failed to generate batch content because no test file is found.'
+        not options.quiet and print(msg)
+        sys.exit(ECODE.BAD)
+
+
+def do_delete_filepath(options):
+    filepath = options.filepath
+
+    if File.is_exist(filepath):
+        is_deleted = File.delete(filepath)
+        fmt = '+++ %s' if is_deleted else '*** %s'
+        not options.quiet and print(fmt % File.message)
+        sys.exit(ECODE.SUCCESS if is_deleted else ECODE.BAD)
+
+    are_deleted = None
+    for file_path in shlex.split(filepath):
+        if file_path == ',':
+            continue
+
+        file_path = file_path.rstrip(',').strip('{').strip('}')
+        is_deleted = File.delete(file_path)
+        fmt = '+++ %s' if is_deleted else '*** %s'
+        not options.quiet and print(fmt % File.message)
+        are_deleted = is_deleted if are_deleted is None else are_deleted and is_deleted
+
+    if are_deleted is None:
+        sys.exit(ECODE.BAD)
+    else:
+        sys.exit(ECODE.SUCCESS if are_deleted else ECODE.BAD)
+
+
+def do_reporting(options):
+    command, operands = options.command, list(options.operands)
+    # feature = ''.join(operands[:1])
+    # operands = operands[1:]
+    name = command
+    validate_usage(name, operands)
+    validate_example_usage(name, operands)
+
+    directory = operands[0] if operands else '.'
+    report_files = DGSReportFile.get_report_files(directory)
+    reporter = DGSReport(*report_files, detail=options.detail)
+    report = reporter.generate()
+    print(report)
+    sys.exit(reporter.exit_code)
