@@ -27,7 +27,9 @@ class FLAG(IntFlag):
     ALL = pow(2, 8)
     DEPENDENCY = pow(2, 9)
     TEMPLATE_STORAGE = pow(2, 10)
-    HELP = pow(2, 11)
+    QUIET = pow(2, 11)
+    DETAIL = pow(2, 12)
+    HELP = pow(2, 13)
 
     BUILD_TEMPLATE = AUTHOR | EMAIL | COMPANY | SAVE_TO | TEMPLATE_ID | REPLACED | HELP
     BUILD_SCRIPT = AUTHOR | EMAIL | COMPANY | SAVE_TO | HELP
@@ -109,6 +111,8 @@ def get_usage_header(name, flags=0):
         '  --all                   showing all information',
         '  --dependency            showing package dependencies',
         '  --template-storage      showing template storage information',
+        '  --quiet                 silent success or fail info',
+        '  --detail                generate detail test execution script or report',
         '  -h, --help              show this help message and exit',
     ]
     if flags:
@@ -163,12 +167,20 @@ class BuildScriptUsage:
     example_usage = get_example_usage('build_script')
 
 
+class BuildBatchUsage:
+    usage = get_usage('build_batch', flags=FLAG.SAVE_TO | FLAG.DETAIL | FLAG.HELP)
+    other_usage = get_usage('build_batch', flags=FLAG.SAVE_TO | FLAG.DETAIL | FLAG.HELP)
+    example_usage = get_example_usage('build_batch')
+
+
 class BuildUsage:
     usage = '\n'.join([
-        Printer.get('build command has two features: template or script'),
+        Printer.get('build command has three features: template, script, or batch'),
         str(BuildTemplateUsage.usage),
         '',
         str(BuildScriptUsage.usage),
+        '',
+        str(BuildBatchUsage.usage),
     ])
 
 
@@ -190,13 +202,21 @@ class TestUsage:
     example_usage = get_example_usage('test')
 
 
+class ReportUsage:
+    usage = get_usage('report', flags=FLAG.DETAIL | FLAG.HELP)
+    other_usage = get_usage('report', flags=FLAG.DETAIL | FLAG.HELP)
+    example_usage = get_example_usage('report')
+
+
 class Usage:
     info = InfoUsage
     build = BuildUsage
     build_template = BuildTemplateUsage
     build_script = BuildScriptUsage
+    build_batch = BuildBatchUsage
     search_template = SearchTemplateUsage
     test = TestUsage
+    report = ReportUsage
 
 
 def validate_usage(name, operands):
