@@ -1,6 +1,10 @@
 """Module containing the logic for utilities."""
 
 import re
+import os
+import filecmp
+import shutil
+import platform
 
 import subprocess
 from copy import deepcopy
@@ -186,6 +190,46 @@ class File:
     def clean(cls):
         cls.message = ''
 
+    @classmethod
+    def is_file(cls, filename):
+        """Check filename is a file
+
+        Parameters
+        ----------
+        filename (str): a file name
+
+        Returns
+        -------
+        bool: True if it is a file, otherwise False
+        """
+        cls.clean()
+        try:
+            file_obj = Path(filename)
+            return file_obj.is_file()
+        except Exception as ex:
+            cls.message = Text(ex)
+            return False
+
+    @classmethod
+    def is_dir(cls, file_path):
+        """Check file_path is a directory
+
+        Parameters
+        ----------
+        file_path (str): a location of file
+
+        Returns
+        -------
+        bool: True if it is a directory, otherwise False
+        """
+        cls.clean()
+        try:
+            file_obj = Path(file_path)
+            return file_obj.is_dir()
+        except Exception as ex:
+            cls.message = Text(ex)
+            return False
+
     @classmethod
     def is_exist(cls, filename):
         """Check file existence
@@ -206,6 +250,95 @@ class File:
             cls.message = Text(ex)
             return False
 
+    @classmethod
+    def copy_file(cls, src, dst):
+        """copy source file to destination
+
+        Parameters
+        ----------
+        src (str): a source of file
+        dst (str): a destination file or directory
+
+        Returns
+        -------
+        str: a copied file if successfully copied, otherwise empty string
+        """
+        cls.clean()
+        try:
+            copied_file = shutil.copy2(src, dst)
+            return copied_file
+        except Exception as ex:
+            cls.message = Text(ex)
+            return ''
+
+    @classmethod
+    def copy_files(cls, src, dst):
+        """copy source file(s) to destination
+
+        Parameters
+        ----------
+        src (str, list): a source of file or files
+        dst (str): a destination directory
+
+        Returns
+        -------
+        list: a list of a copied file if successfully copied, otherwise empty list
+        """
+        cls.clean()
+        cls.make_directory(dst, showed=False)
+
+        empty_list = []
+        if Misc.is_list(src):
+            copied_files = empty_list
+            for file in src:
+                copied_file = cls.copy_file(file, dst)
+                if cls.message:
+                    return copied_files
+                copied_files.append(copied_file)
+            return copied_files
+        else:
+            copied_file = cls.copy_file(src, dst)
+            if cls.message:
+                return empty_list
+            else:
+                return [copied_file]
+
+    @classmethod
+    def make_directory(cls, file_path, showed=True):
+        """create a directory
+
+        Parameters
+        ----------
+        file_path (str): a file location
+        showed (bool): showing the message of creating folder
+
+        Returns
+        -------
+        bool: True if created, otherwise False
+        """
+        cls.clean()
+
+        if cls.is_exist(file_path):
+            if cls.is_dir(file_path):
+                cls.message = '%r directory is already existed.' % file_path
+                return True
+            else:
+                cls.message = 'Existing %r IS NOT a directory.' % file_path
+                return False
+
+        try:
+            file_obj = Path(file_path)
+            file_obj.mkdir(parents=True, exist_ok=True)
+            fmt = '{:%Y-%m-%d %H:%M:%S.%f} - {} folder is created.'
+            showed and print(fmt.format(datetime.now(), file_path))
+            cls.message = '{} folder is created.'.format(file_path)
+            return True
+        except Exception as ex:
+            cls.message = Text(ex)
+            return False
+
+    make_dir = make_directory
+
     @classmethod
     def create(cls, filename, showed=True):
         """Check file existence
@@ -278,6 +411,38 @@ class File:
             cls.message = fmt.format(file_path)
             return ''
 
+    @classmethod
+    def get_filepath_timestamp_format1(cls, *args, prefix='', extension='',
+                                       is_full_path=False, ref_datetime=None):
+        """Create a file path with timestamp format1
+
+        Parameters
+        ----------
+        args (tuple): a list of file items
+        prefix (str): a prefix for base name of file path.  Default is empty.
+        extension (str): an extension of file.  Default is empty.
+        is_full_path (bool): show absolute full path.  Default is False.
+        ref_datetime (datetime.datetime): a reference datetime instance.
+
+        Returns
+        -------
+        str: a file path with timestamp format1.
+        """
+        lst = list(args)
+
+        ref_datetime = ref_datetime if isinstance(ref_datetime, datetime) else datetime.now()
+
+        basename = '{:%Y%B%d_%H%M%S}'.format(ref_datetime)
+        if prefix.strip():
+            basename = '%s_%s' % (prefix.strip(), basename)
+
+        if extension.strip():
+            basename = '%s.%s' % (basename, extension.strip().strip('.'))
+
+        lst.append(basename)
+        file_path = cls.get_path(*lst) if is_full_path else str(Path(*lst))
+        return file_path
+
     @classmethod
     def get_content(cls, file_path):
         """get content of file
@@ -409,10 +574,11 @@ class File:
             filepath = File.get_path(filename)
             file_obj = Path(filepath)
             if file_obj.is_dir():
-                file_obj.rmdir()
+                shutil.rmtree(filename)
+                cls.message = 'Successfully deleted "{}" folder'.format(filename)
             else:
                 file_obj.unlink()
-            cls.message = 'Successfully deleted "{}" file'.format(filename)
+                cls.message = 'Successfully deleted "{}" file'.format(filename)
             return True
         except Exception as ex:
             cls.message = Text(ex)
@@ -434,6 +600,85 @@ class File:
         new_name = filename.replace(home_dir, replaced)
         return new_name
 
+    @classmethod
+    def is_duplicate_file(cls, file, source):
+        if Misc.is_list(source):
+            for other_file in source:
+                chk = filecmp.cmp(file, other_file)
+                if chk:
+                    return True
+            return False
+        else:
+            chk = filecmp.cmp(file, source)
+            return chk
+
+    @classmethod
+    def get_list_of_filenames(cls, top='.', pattern='', excluded_duplicate=True):
+        cls.clean()
+
+        empty_list = []
+
+        if not cls.is_exist(top):
+            File.message = 'The provided path IS NOT existed.'
+            return empty_list
+
+        if cls.is_file(top):
+            if pattern:
+                result = [top] if re.search(pattern, top) else empty_list
+            else:
+                result = [top]
+            return result
+
+        try:
+            lst = []
+            for dir_path, _dir_names, file_names in os.walk(top):
+                for file_name in file_names:
+                    if pattern and not re.search(pattern, file_name):
+                        continue
+                    file_path = str(Path(dir_path, file_name))
+
+                    if excluded_duplicate:
+                        is_duplicated = cls.is_duplicate_file(file_path, lst)
+                        not is_duplicated and lst.append(file_path)
+                    else:
+                        lst.append(file_path)
+            return lst
+
+        except Exception as ex:
+            failure = Text(ex)
+            cls.message = failure
+            return empty_list
+
+    @classmethod
+    def quicklook(cls, filename, lookup=''):
+        if not cls.is_exist(filename):
+            cls.message = '%r file is not existed.' % filename
+            return False
+
+        content = cls.get_content(filename)
+
+        if not content.strip():
+            if content.strip() == lookup.strip():
+                return True
+            else:
+                return False
+
+        if not lookup.strip():
+            return True
+
+        if cls.message:
+            return False
+
+        if lookup in content:
+            return True
+        else:
+            try:
+                match = re.search(lookup, content)
+                return bool(match)
+            except Exception as ex:     # noqa
+                cls.message = Text(ex)
+                return False
+
 
 class Misc:
 
@@ -498,19 +743,48 @@ class Misc:
 
     @classmethod
     def is_integer(cls, obj):
-        return isinstance(obj, int)
+        if isinstance(obj, int):
+            return True
+        elif cls.is_string(obj):
+            chk = obj.strip().isdigit()
+            return chk
+        else:
+            return False
 
     @classmethod
     def is_boolean(cls, obj):
-        return isinstance(obj, bool)
+        if isinstance(obj, bool):
+            return True
+        elif cls.is_string(obj):
+            val = obj.strip().lower()
+            chk = val == 'true' or val == 'false'
+            return chk
+        elif cls.is_integer(obj):
+            chk = int(obj) == 0 or int(obj) == 1
+            return chk
+        elif cls.is_float(obj):
+            chk = float(obj) == 0 or float(obj) == 1
+            return chk
+        else:
+            return False
 
     @classmethod
     def is_float(cls, obj):
-        return isinstance(obj, float)
+        if isinstance(obj, (float, int)):
+            return True
+        elif cls.is_string(obj):
+            try:
+                float(obj)
+                return True
+            except Exception as ex:     # noqa
+                return False
+        else:
+            return False
 
     @classmethod
     def is_number(cls, obj):
         result = cls.is_boolean(obj)
+        result |= cls.is_integer(obj)
         result |= cls.is_float(obj)
         return result
 
@@ -630,6 +904,26 @@ class Misc:
         substitute(new_data, variables)
         return new_data
 
+    @classmethod
+    def is_window_os(cls):
+        chk = platform.system().lower() == 'windows'
+        return chk
+
+    @classmethod
+    def is_mac_os(cls):
+        chk = platform.system().lower() == 'darwin'
+        return chk
+
+    @classmethod
+    def is_linux_os(cls):
+        chk = platform.system().lower() == 'linux'
+        return chk
+
+    @classmethod
+    def is_nix_os(cls):
+        chk = cls.is_linux_os() or cls.is_mac_os()
+        return chk
+
 
 class MiscArgs:
     @classmethod
@@ -663,20 +957,23 @@ class MiscArgs:
                 if re.match(pattern, flag) and val.strip():
                     result.is_file = True
                     result.filename = val.strip()
+                    return result
                 else:
-                    if flag != 'val1' or flag != 'val2':
-                        if val.strip():
+                    val_txt = ''.join(val) if Misc.is_list(val) else str(val)
+                    val_txt = val_txt.strip()
+                    if flag == 'val1' or flag == 'val2' and val_txt:
+                        result.is_data = True
+                        result.data = val_txt
+                        return result
+                    else:
+                        if val_txt:
                             result.is_data = True
-                            result.data = val.strip()
+                            result.data = val_txt
                             return result
 
-            if result.val1 or result.val2:
-                result.is_data = True
-                return result
-            else:
-                result.is_parsed = False
-                result.failure = 'Invalid data'
-                return result
+            result.is_parsed = False
+            result.failure = 'Invalid data'
+            return result
 
         except Exception as ex:
             result.failure = '{}: {}'.format(type(ex).__name__, ex)
